summaryrefslogtreecommitdiffstats
path: root/core/java/android/accessibilityservice
diff options
context:
space:
mode:
authorSvetoslav Ganov <svetoslavganov@google.com>2012-05-08 13:46:48 -0700
committerSvetoslav Ganov <svetoslavganov@google.com>2012-05-08 14:29:33 -0700
commit87bd0dccf7f2558ea1a5e0fce523aea022709834 (patch)
tree9a875a9fd9784bedfe2f2d17d088d30776998b1f /core/java/android/accessibilityservice
parent6e24d0c69366a29082cbc3962fe67acf533ef1bc (diff)
downloadframeworks_base-87bd0dccf7f2558ea1a5e0fce523aea022709834.zip
frameworks_base-87bd0dccf7f2558ea1a5e0fce523aea022709834.tar.gz
frameworks_base-87bd0dccf7f2558ea1a5e0fce523aea022709834.tar.bz2
Renaming the constants for activation and long press.
1. We will have a double tap to activate an item and tap and hold to perform a long press. Change-Id: Ibd9d8774e5a4693d8868d1128e55a82ff0c3a80b
Diffstat (limited to 'core/java/android/accessibilityservice')
-rw-r--r--core/java/android/accessibilityservice/AccessibilityService.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/core/java/android/accessibilityservice/AccessibilityService.java b/core/java/android/accessibilityservice/AccessibilityService.java
index b644dd1..c559e54 100644
--- a/core/java/android/accessibilityservice/AccessibilityService.java
+++ b/core/java/android/accessibilityservice/AccessibilityService.java
@@ -284,14 +284,14 @@ public abstract class AccessibilityService extends Service {
public static final int GESTURE_SWIPE_DOWN_AND_RIGHT = 16;
/**
* The user has performed a two finger tap gesture on the touch screen.
*/
- public static final int GESTURE_TWO_FINGER_TAP = 17;
+ public static final int GESTURE_DOUBLE_TAP = 17;
/**
* The user has performed a two finger long press gesture on the touch screen.
*/
- public static final int GESTURE_TWO_FINGER_LONG_PRESS = 18;
+ public static final int GESTURE_TAP_AND_HOLD = 18;
/**
* The {@link Intent} that must be declared as handled by the service.
@@ -408,8 +408,8 @@ public abstract class AccessibilityService extends Service {
* @see #GESTURE_SWIPE_RIGHT_AND_DOWN
* @see #GESTURE_CLOCKWISE_CIRCLE
* @see #GESTURE_COUNTER_CLOCKWISE_CIRCLE
- * @see #GESTURE_TWO_FINGER_TAP
- * @see #GESTURE_TWO_FINGER_LONG_PRESS
+ * @see #GESTURE_DOUBLE_TAP
+ * @see #GESTURE_TAP_AND_HOLD
*/
protected boolean onGesture(int gestureId) {
// TODO: Describe the default gesture processing in the javaDoc once it is finalized.
@@ -284,14 +284,14 @@ public abstract class AccessibilityService extends Service {
public static final int GESTURE_SWIPE_DOWN_AND_RIGHT = 16;
/**
- * The user has performed a two finger tap gesture on the touch screen.
+ * The user has performed a double tap gesture on the touch screen.
*/
@@ -284,14 +284,14 @@ public abstract class AccessibilityService extends Service {
/**
- * The user has performed a two finger long press gesture on the touch screen.
+ * The user has performed a tap and hold gesture on the touch screen.
*/